# Changelog

## [integrations/azure_ai_search-v0.1.0] - 2024-11-21

### 🚀 Features

- Add Azure AI Search integration (#1122)
- Add BM25 and Hybrid Search Retrievers to Azure AI Search Integration (#1175)

### 🌀 Miscellaneous

- Enable kwargs in SearchIndex and Embedding Retriever (#1185)
- Fix: Fix tag name for version release (#1206)

<!-- generated by git-cliff -->
